﻿using Borepin.Model;
using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Threading.Tasks;

namespace Borepin.Service.Connections
{
    public class ConnectionService : IConnectionService
    {
        #region Private Properties
        private readonly IPreferenceService _PreferenceService;
        #endregion

        public ConnectionService(IPreferenceService preferenceService)
        {
            _PreferenceService = preferenceService;
        }

        public Task<List<Connection>> GetConnectionList()
        {
            return Task.FromResult(JsonConvert.DeserializeObject<List<Connection>>(_PreferenceService.Get("connection_list", "[]")));
        }

        public Task<bool> AddConnection(Connection connection)
        {
            List<Connection> connection_list = JsonConvert.DeserializeObject<List<Connection>>(_PreferenceService.Get("connection_list", "[]"));

            if(connection_list.Contains(connection))
            {
                throw new ArgumentException("Connection allready exist");
            }

            connection_list.Add(connection);

            _PreferenceService.Set("connection_list", JsonConvert.SerializeObject(connection_list));

            return Task.FromResult(true);
        }

        public Task<bool> RemoveConnection(Connection connection)
        {
            List<Connection> connection_list = JsonConvert.DeserializeObject<List<Connection>>(_PreferenceService.Get("connection_list", "[]"));

            if (!connection_list.Contains(connection))
            {
                throw new ArgumentException("Connection does not exist");
            }

            connection_list.RemoveAll(x => x.Equals(connection));

            _PreferenceService.Set("connection_list", JsonConvert.SerializeObject(connection_list));

            return Task.FromResult(true);
        }

        public Task<bool> LogConnect(Connection connection)
        {
            List<Connection> connection_list = JsonConvert.DeserializeObject<List<Connection>>(_PreferenceService.Get("connection_list", "[]"));

            if (!connection_list.Contains(connection))
            {
                throw new ArgumentException("Connection does not exist");
            }

            int index = connection_list.IndexOf(connection);
            Connection connection_update = connection_list[index];
            connection_update.LastTime = DateTime.UtcNow;
            connection_list[index] = connection_update;

            _PreferenceService.Set("connection_list", JsonConvert.SerializeObject(connection_list));

            return Task.FromResult(true);
        }
    }
}
